Type: Package
Package: msigdbr
Title: MSigDB Gene Sets for Multiple Organisms in a Tidy Data Format
Version: 26.1.0
Authors@R: 
    person("Igor", "Dolgalev", , "igor.dolgalev@nyumc.org", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-4451-126X"))
Description: Provides the 'Molecular Signatures Database' (MSigDB) gene
    sets typically used with the 'Gene Set Enrichment Analysis' (GSEA)
    software (Subramanian et al. 2005 <doi:10.1073/pnas.0506580102>,
    Liberzon et al. 2015 <doi:10.1016/j.cels.2015.12.004>, Castanza et al.
    2023 <doi:10.1038/s41592-023-02014-7>) as an R data frame. The package
    includes the human genes as listed in MSigDB as well as the
    corresponding symbols and IDs for frequently studied model organisms
    such as mouse, rat, pig, fly, and yeast.
License: MIT + file LICENSE
URL: https://igordot.github.io/msigdbr/
BugReports: https://github.com/igordot/msigdbr/issues
Depends: R (>= 4.1)
Imports: assertthat, babelgene (>= 22.9), curl, dplyr (>= 1.1.1),
        lifecycle, methods, rlang, tibble, tidyselect (>= 1.2.0), tools
Suggests: knitr, rmarkdown, roxygen2, testthat
Config/Needs/website: rmarkdown
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-03-12 03:54:54 UTC; id460
Author: Igor Dolgalev [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4451-126X>)
Maintainer: Igor Dolgalev <igor.dolgalev@nyumc.org>
Repository: CRAN
Date/Publication: 2026-03-12 07:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 16:14:54 UTC; unix
